#!/usr/bin/env bash
# Set bash to 'debug' mode, it will exit on :
# -e 'error', -u 'undefined variable', -o ... 'error in pipeline', -x 'print commands',
set -e
set -u
set -o pipefail

source /share02/SLC/users/okamoto/project/neural_TTS/hi-fi-captain/espnet/tools/venv/bin/activate

fs=24000
n_fft=1024
n_shift=256

opts="--audio_format wav "

train_set=tr_no_dev_ja-JP_M
valid_set=dev_ja-JP_M
test_sets="eval_ja-JP_M"
dumpdir="dump/ja-JP_M_24k"
expdir="exp/ja-JP_M_24k"

train_config=conf/tuning/train_jets_24k.yaml
inference_config=

# g2p=g2p_en # Include word separator
#g2p=g2p_en_no_space # Include no word separator
g2p=pyopenjtalk_prosody

opts+="--min_wav_duration 0.8 --write_collected_feats true "

./tts.sh \
    --stage 2 \
    --stop_stage 5 \
    --dumpdir "${dumpdir}" \
    --expdir "${expdir}" \
    --lang jp \
    --feats_type raw \
    --fs "${fs}" \
    --n_fft "${n_fft}" \
    --n_shift "${n_shift}" \
    --token_type phn \
    --cleaner jaconv \
    --g2p "${g2p}" \
    --train_config "${train_config}" \
    --inference_config "${inference_config}" \
    --train_set "${train_set}" \
    --valid_set "${valid_set}" \
    --test_sets "${test_sets}" \
    --srctexts "data/${train_set}/text" \
    --tts_task gan_tts \
    ${opts} "$@"
